@@ -87,7 +87,7 @@ build_fixed_volume_gas(void)
  */
 		if (debug_prep == TRUE)
 		{
-			output_msg(sformatf( "\n\tMass balance summations %s.\n\n",
+			output_msg(sformatf( "\n\tMass balance summations %s.\n",
 					   phase_ptr->name));
 		}
 
@@ -211,27 +211,27 @@ build_fixed_volume_gas(void)
 				}
 				col = master_ptr->unknown->number;
 				coef = coef_elt * rxn_ptr->coef;
-				store_jacob(&(gas_unknowns[i]->moles),
-							&(array[row + col]), coef);
 				if (debug_prep == TRUE)
 				{
-					output_msg(sformatf( "\t\t%-24s%10.3f\t%d\t%d\n",
+					output_msg(sformatf( "\t\t%-24s%10.3f\t%d\t%d",
 							   master_ptr->s->name, (double) coef,
 							   row / (count_unknowns + 1), col));
 				}
+				store_jacob(&(gas_unknowns[i]->moles),
+					&(my_array[row + col]), coef);
 			}
 			if (gas_phase_ptr->Get_type() == cxxGasPhase::GP_PRESSURE)
 			{
 				/* derivative wrt total moles of gas */
-				store_jacob(&(phase_ptr->fraction_x),
-							&(array[row + gas_unknown->number]), coef_elt);
 				if (debug_prep == TRUE)
 				{
-					output_msg(sformatf( "\t\t%-24s%10.3f\t%d\t%d\n",
+					output_msg(sformatf( "\t\t%-24s%10.3f\t%d\t%d",
 							   "gas moles", (double) elt_list[j].coef,
 							   row / (count_unknowns + 1),
 							   gas_unknown->number));
 				}
+				store_jacob(&(phase_ptr->fraction_x),
+					&(my_array[row + gas_unknown->number]), coef_elt);
 			}
 		}
 /*
@@ -303,13 +303,13 @@ build_fixed_volume_gas(void)
 					}
 					col = master_ptr->unknown->number;
 					coef = rxn_ptr->coef;
-					store_jacob(&(phase_ptr->p_soln_x), &(array[row + col]), coef);
 					if (debug_prep == TRUE)
 					{
-						output_msg(sformatf( "\t\t%-24s%10.3f\t%d\t%d\n",
+						output_msg(sformatf( "\t\t%-24s%10.3f\t%d\t%d",
 							master_ptr->s->name, (double) coef,
 							row / (count_unknowns + 1), col));
 					}
+					store_jacob(&(phase_ptr->p_soln_x), &(my_array[row + col]), coef);
 				}
 			}
 		}
@@ -589,8 +589,7 @@ calc_PR(void)
 		{
 			phi = B_r * (rz - 1) - log(rz - B) + A / (2.828427 * B) * (B_r - 2.0 * phase_ptr->pr_aa_sum2 / a_aa_sum) *
 				  log((rz + 2.41421356 * B) / (rz - 0.41421356 * B));
-			if (phi > 4.44)
-				phi = 4.44;
+			phi = (phi > 4.44 ? 4.44 : (phi < -3 ? -3 : phi));
 		}
 		else
 			phi = -3.0; // fugacity coefficient > 0.05
