@@ -938,7 +938,11 @@ punch_calculate_values(void)
 					calculate_value_ptr->name);
 				error_msg(error_string, STOP);
 			}
+#ifdef NPP
+			if (isnan(rate_moles))
+#else
 			if (rate_moles == NAN)
+#endif
 			{
 				error_string = sformatf( "Calculated value not SAVEed for %s.",
 					calculate_value_ptr->name);
@@ -1207,7 +1211,11 @@ calculate_values(void)
 						calculate_value_ptr->name);
 					error_msg(error_string, STOP);
 				}
+#ifdef NPP
+				if (isnan(rate_moles))
+#else
 				if (rate_moles == NAN)
+#endif
 				{
 					error_string = sformatf( "Calculated value not SAVEed for %s.",
 						calculate_value_ptr->name);
@@ -1270,7 +1278,11 @@ calculate_values(void)
 						calculate_value_ptr->name);
 					error_msg(error_string, STOP);
 				}
+#ifdef NPP
+				if (isnan(rate_moles))
+#else
 				if (rate_moles == NAN)
+#endif
 				{
 					error_string = sformatf( "Calculated value not SAVEed for %s.",
 						calculate_value_ptr->name);
